@@ -189,7 +189,7 @@ LM13i=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                "VIF"=vif,
-                grafico)
+                grafico,
+                "VIF"=vif)
   print(graficos)
 }
