@@ -163,7 +163,7 @@ LM2i3=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                "VIF"=vif,
-                grafico)
+                grafico,
+                "VIF"=vif)
   print(graficos)
 }
