@@ -17,6 +17,8 @@
 #' @param pointsize	shape size
 #' @param linesize	line size
 #' @param pointshape format point (default is 21)
+#' @param colorline Color lines
+#' @param fillshape Fill shape
 #' @param round round equation
 #' @param xname.formula Name of x in the equation
 #' @param yname.formula Name of y in the equation
@@ -59,6 +61,8 @@ linear.plateau=function(trat,resp,
                       pointsize = 4.5,
                       linesize = 0.8,
                       pointshape = 21,
+                      fillshape = "gray",
+                      colorline = "black",
                       round=NA,
                       xname.formula="x",
                       yname.formula="y",
@@ -114,7 +118,7 @@ linear.plateau=function(trat,resp,
     coef2=round(coef(model2)[2],round)
     coef3=round(breakpoint,round)}
 
-  s <- sprintf("~~~%s == %e %s %e * %s ~(%s<%e) ~~~~~ italic(R^2) ==  %0.2f",
+  s <- sprintf("~~~%s == %e %s %e * %s ~(%s~'<'~%e) ~~~~~ italic(R^2) ==  %0.2f",
                yname.formula,
                coef1,
                ifelse(coef2 >= 0, "+", "-"),
@@ -139,11 +143,11 @@ linear.plateau=function(trat,resp,
                                                  width=width.bar,
                                                  size=linesize)}
     graph=graph+
-      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
     graph=ggplot(data.frame(trat,resp),aes(x=trat,y=resp))
     graph=graph+
-      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   xp=seq(min(trat),max(trat),length=sample.curve)
   yp=predict(lp_model,newdata=data.frame(trat=xp))
   preditos=data.frame(x=xp,y=yp)
@@ -155,7 +159,7 @@ linear.plateau=function(trat,resp,
     geom_line(data=preditos,aes(x=x,
                                 y=y,
                                 color="black"),size=linesize)+
-    scale_color_manual(name="",values="black",label=parse(text = equation))+
+    scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
           legend.position = legend.position,
